@@ -1,7 +1,7 @@
 import logging
 from django.db import models
 from six import python_2_unicode_compatible
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 LOG_LEVELS = (
     (logging.NOTSET, _('NotSet')),
